@@ -295,7 +295,7 @@ Map::OverlayClouds(const unsigned char *clouds)
         d.Quality(options->JPEGQuality());
         if (!d.Write(dayFile.c_str()))
         {
-            stringstream errStr;
+            ostringstream errStr;
             errStr << "Can't create " << dayFile << "\n";
             xpExit(errStr.str(), __FILE__, __LINE__);
         }
@@ -305,14 +305,14 @@ Map::OverlayClouds(const unsigned char *clouds)
         n.Quality(options->JPEGQuality());
         if (!n.Write(nightFile.c_str()))
         {
-            stringstream errStr;
+            ostringstream errStr;
             errStr << "Can't create " << nightFile << "\n";
             xpExit(errStr.str(), __FILE__, __LINE__);
         }
 
         if (options->Verbosity() > 0)
         {
-            stringstream msg;
+            ostringstream msg;
             msg << "Wrote " << dayFile << " and " << nightFile 
                 << ".\n";
             xpMsg(msg.str(), __FILE__, __LINE__);
@@ -372,7 +372,7 @@ Map::AddShadows(map<double, Planet *> &planetsFromSunMap)
 
         if (options->Verbosity() > 1)
         {
-            stringstream msg;
+            ostringstream msg;
             msg << "separation between " << body_string[p->Index()] 
                 << " and " << body_string[target_->Index()] << " is " 
                 << sep/deg_to_rad << "\n";
@@ -458,7 +458,8 @@ Map::AddShadow(Planet *p, const double sun_size)
                     dayData_[ipos] = (unsigned char) ((1 - covered)
                                                       * dayData_[ipos]
                                                       + covered 
-                                                      * nightData_[ipos++]);
+                                                      * nightData_[ipos]);
+                    ipos++;
                 }
             }
         }
@@ -595,7 +596,7 @@ Map::Reduce(const int factor)
     Options *options = Options::getInstance();
     if (options->Verbosity() > 1)
     {
-        stringstream msg;
+        ostringstream msg;
         msg << "Shrinking map by 2^" << factor << "\n";;
         xpMsg(msg.str(), __FILE__, __LINE__);
     }
