@@ -66,6 +66,7 @@ Options::Options() :
     extension_(defaultMapExt),
     font_(defaultFont),
     fontSize_(12),
+    fork_(false), 
     fov_(-1),
     fovMode_(RADIUS),
     geometryMask_(NoValue),
@@ -188,6 +189,7 @@ Options::parseArgs(int argc, char **argv)
             {"ephemeris_file", required_argument, NULL, JPL_FILE},
             {"font",           required_argument, NULL, FONT},
             {"fontsize",       required_argument, NULL, FONTSIZE},
+            {"fork",           no_argument,       NULL, FORK},
             {"fov",            required_argument, NULL, FOV},
             {"geometry",       required_argument, NULL, GEOMETRY},
             {"gmtlabel",       no_argument,       NULL, UTCLABEL},
@@ -239,6 +241,7 @@ Options::parseArgs(int argc, char **argv)
             {"vroot",          no_argument,       NULL, VROOT},
             {"wait",           required_argument, NULL, WAIT},
             {"window",         no_argument,       NULL, WINDOW},
+            {"window-id",      required_argument, NULL, XWINID},
             {"window_title",   required_argument, NULL, WINDOWTITLE},
             {"XID",            required_argument, NULL, XWINID},
             {"xscreensaver",   no_argument,       NULL, VROOT},
@@ -339,6 +342,9 @@ Options::parseArgs(int argc, char **argv)
 #endif
         }
         break;
+	case FORK:
+	    fork_ = true;
+	    break;
         case FOV:
             sscanf(optarg, "%lf", &fov_);
             if (fov_ <= 0) 
@@ -360,32 +366,12 @@ Options::parseArgs(int argc, char **argv)
         }
         break;
         case HIBERNATE:
-#ifdef HAVE_XSS
             sscanf(optarg, "%lu", &hibernate_);
             hibernate_ *= 1000;
-#else
-            {
-                ostringstream errMsg;
-                errMsg << "This binary was built without the X Screensaver extensions.\n"
-                       << "The -" << long_options[option_index].name 
-                       << " option will be ignored.\n";
-                xpWarn(errMsg.str(), __FILE__, __LINE__);
-            }
-#endif
             break;
         case IDLEWAIT:
-#ifdef HAVE_XSS
             sscanf(optarg, "%lu", &idleWait_);
             idleWait_ *= 1000;
-#else
-            {
-                ostringstream errMsg;
-                errMsg << "This binary was built without the X Screensaver extensions.\n"
-                       << "The -" << long_options[option_index].name 
-                       << " option will be ignored.\n";
-                xpWarn(errMsg.str(), __FILE__, __LINE__);
-            }
-#endif
             break;
         case INTERPOLATE_ORIGIN_FILE:
             interpolateOriginFile_ = true;
@@ -600,7 +586,7 @@ Options::parseArgs(int argc, char **argv)
             break;
         case RADIUS:
             sscanf(optarg, "%lf", &radius_);
-            if (radius_ < 0)
+            if (radius_ <= 0)
                 xpExit("radius must be positive\n", __FILE__, __LINE__);
 
             radius_ /= 100;
