@@ -317,7 +317,7 @@ drawMultipleBodies(DisplayBase *display, Planet *target,
 
     if (options->Verbosity() > 0)
     {
-        stringstream msg;
+        ostringstream msg;
         char buffer[256];
         snprintf(buffer, 256, "%10s%14s%14s%14s%14s%14s%14s%14s%14s\n", 
                  "Name", "Dist", "X", "Y", "radius",
@@ -376,7 +376,7 @@ drawMultipleBodies(DisplayBase *display, Planet *target,
 
         if (options->Verbosity() > 0)
         {
-            stringstream msg;
+            ostringstream msg;
             char buffer[256];
             snprintf(buffer, 256, 
                      "%10s%14.4f%14.4f%14.4f%14.4f%14.4f%14.4f%14.4f%14.4f\n", 
@@ -390,9 +390,7 @@ drawMultipleBodies(DisplayBase *display, Planet *target,
 
         if (pR <= 1)
         {
-            display->setPixel(static_cast<int> (pX + 0.5), 
-                              static_cast<int> (pY + 0.5), 
-                              currentProperties->Color());
+            display->setPixel(pX, pY, currentProperties->Color());
             if (current_planet->Index() == SUN) 
                 drawSun(display, pX, pY, 1, currentProperties->Color());
 
